From: Dhruv Chawla <[email protected]>

Signed-off-by: Dhruv Chawla <[email protected]>

gcc/ada/ChangeLog:

        * adaint.c (__gnat_set_OWNER_ACL): Fix typos.
        * aux-io.c: Likewise.
        * cio.c: Likewise.
        * cstreams.c: Likewise.
        * doc/gnat_rm/gnat_language_extensions.rst: Likewise.
        * doc/gnat_rm/implementation_defined_attributes.rst: Likewise.
        * doc/gnat_rm/implementation_defined_characteristics.rst: Likewise.
        * doc/gnat_rm/implementation_defined_pragmas.rst: Likewise.
        * doc/gnat_rm/interfacing_to_other_languages.rst: Likewise.
        * doc/gnat_rm/representation_clauses_and_pragmas.rst: Likewise.
        * doc/gnat_rm/standard_and_implementation_defined_restrictions.rst: 
Likewise.
        * doc/gnat_rm/the_gnat_library.rst: Likewise.
        * doc/gnat_ugn/building_executable_programs_with_gnat.rst: Likewise.
        * doc/gnat_ugn/gnat_and_program_execution.rst: Likewise.
        * doc/gnat_ugn/gnat_utility_programs.rst: Likewise.
        * doc/gnat_ugn/platform_specific_information.rst: Likewise.
        * doc/gnat_ugn/the_gnat_compilation_model.rst: Likewise.
        * doc/share/conf.py: Likewise.
        * gcc-interface/decl.cc (components_to_record): Likewise.
        * gcc-interface/misc.cc (gnat_get_array_descr_info): Likewise.
        (get_array_bit_stride): Likewise.
        * gcc-interface/trans.cc (Loop_Statement_to_gnu): Likewise.
        (gnat_to_gnu): Likewise.
        * gcc-interface/utils.cc (gnat_pushdecl): Likewise.
        (maybe_pad_type): Likewise.
        (finish_record_type): Likewise.
        (process_deferred_decl_context): Likewise.
        * gnat_rm.texi: Likewise.
        * gnat_ugn.texi: Likewise.
        * gnathtml.pl: Likewise.
        * gsocket.h: Likewise.
        * init.c (__gnat_handle_vms_condition): Likewise.
        (GNAT$STOP): Likewise.
        * raise-gcc.c (db_phases): Likewise.
        * rtinit.c (__gnat_runtime_initialize): Likewise.
        * sigtramp-arm-qnx.c: Likewise.
        * sigtramp-vxworks-target.h (defined): Likewise.
        * sigtramp-vxworks.c: Likewise.
        * sysdep.c: Likewise.
        * terminals.c (defined): Likewise.
        (__gnat_new_tty): Likewise.
        (__gnat_close_tty): Likewise.
        (__gnat_tty_name): Likewise.
        * tracebak.c (PC_ADJUST): Likewise.
---
 gcc/ada/adaint.c                              |  2 +-
 gcc/ada/aux-io.c                              |  2 +-
 gcc/ada/cio.c                                 |  2 +-
 gcc/ada/cstreams.c                            |  2 +-
 .../doc/gnat_rm/gnat_language_extensions.rst  |  2 +-
 .../implementation_defined_attributes.rst     | 10 +++----
 ...implementation_defined_characteristics.rst |  2 +-
 .../implementation_defined_pragmas.rst        |  6 ++---
 .../interfacing_to_other_languages.rst        |  2 +-
 .../representation_clauses_and_pragmas.rst    |  2 +-
 ...nd_implementation_defined_restrictions.rst |  2 +-
 gcc/ada/doc/gnat_rm/the_gnat_library.rst      |  2 +-
 ...building_executable_programs_with_gnat.rst |  2 +-
 .../gnat_ugn/gnat_and_program_execution.rst   | 10 +++----
 .../doc/gnat_ugn/gnat_utility_programs.rst    |  4 +--
 .../platform_specific_information.rst         |  4 +--
 .../gnat_ugn/the_gnat_compilation_model.rst   |  4 +--
 gcc/ada/doc/share/conf.py                     |  2 +-
 gcc/ada/gcc-interface/decl.cc                 |  2 +-
 gcc/ada/gcc-interface/misc.cc                 |  6 ++---
 gcc/ada/gcc-interface/trans.cc                |  4 +--
 gcc/ada/gcc-interface/utils.cc                |  8 +++---
 gcc/ada/gnat_rm.texi                          | 26 +++++++++----------
 gcc/ada/gnat_ugn.texi                         | 20 +++++++-------
 gcc/ada/gnathtml.pl                           |  2 +-
 gcc/ada/gsocket.h                             |  2 +-
 gcc/ada/init.c                                |  6 ++---
 gcc/ada/raise-gcc.c                           |  4 +--
 gcc/ada/rtinit.c                              |  2 +-
 gcc/ada/sigtramp-arm-qnx.c                    |  2 +-
 gcc/ada/sigtramp-vxworks-target.h             |  4 +--
 gcc/ada/sigtramp-vxworks.c                    |  2 +-
 gcc/ada/sysdep.c                              |  2 +-
 gcc/ada/terminals.c                           |  8 +++---
 gcc/ada/tracebak.c                            |  2 +-
 35 files changed, 82 insertions(+), 82 deletions(-)

diff --git a/gcc/ada/adaint.c b/gcc/ada/adaint.c
index 7147b03f5bd..bd367a76c57 100644
--- a/gcc/ada/adaint.c
+++ b/gcc/ada/adaint.c
@@ -2050,7 +2050,7 @@ __gnat_set_OWNER_ACL (TCHAR *wname,
 
   if (AccessMode == SET_ACCESS)
     {
-      /*  SET_ACCESS, we want to set an explicte set of permissions, do not
+      /*  SET_ACCESS, we want to set an explicit set of permissions, do not
          merge with current DACL.  */
       if (SetEntriesInAcl (1, &ea, NULL, &pNewDACL) != ERROR_SUCCESS)
        return;
diff --git a/gcc/ada/aux-io.c b/gcc/ada/aux-io.c
index b25bdb6e935..ae42f410de3 100644
--- a/gcc/ada/aux-io.c
+++ b/gcc/ada/aux-io.c
@@ -37,7 +37,7 @@
 #endif
 
 /* Don't use macros versions of this functions on VxWorks since they cause
-   imcompatible changes in some VxWorks versions */
+   incompatible changes in some VxWorks versions */
 #ifdef __vxworks
 #undef getchar
 #undef putchar
diff --git a/gcc/ada/cio.c b/gcc/ada/cio.c
index 6e702d94ddd..2c8e8661671 100644
--- a/gcc/ada/cio.c
+++ b/gcc/ada/cio.c
@@ -57,7 +57,7 @@ extern "C" {
 #endif
 
 /* Don't use macros versions of this functions on VxWorks since they cause
-   imcompatible changes in some VxWorks versions */
+   incompatible changes in some VxWorks versions */
 #ifdef __vxworks
 #undef getchar
 #undef putchar
diff --git a/gcc/ada/cstreams.c b/gcc/ada/cstreams.c
index 54b997306b5..e7f4d8d38fd 100644
--- a/gcc/ada/cstreams.c
+++ b/gcc/ada/cstreams.c
@@ -88,7 +88,7 @@ extern "C" {
 #endif
 
 /* Don't use macros versions of this functions on VxWorks since they cause
-   imcompatible changes in some VxWorks versions */
+   incompatible changes in some VxWorks versions */
 #ifdef __vxworks
 #undef getchar
 #undef putchar
diff --git a/gcc/ada/doc/gnat_rm/gnat_language_extensions.rst 
b/gcc/ada/doc/gnat_rm/gnat_language_extensions.rst
index cd5391e6f69..2dbd146a70c 100644
--- a/gcc/ada/doc/gnat_rm/gnat_language_extensions.rst
+++ b/gcc/ada/doc/gnat_rm/gnat_language_extensions.rst
@@ -1501,7 +1501,7 @@ descendant of T (including T itself)
 * shall have a Size that does not exceed the specified value; and
 
 * shall have a (possibly inherited) ``Size'Class`` aspect that does not exceed
-  the specifed value; and
+  the specified value; and
 
 * shall be undiscriminated; and
 
diff --git a/gcc/ada/doc/gnat_rm/implementation_defined_attributes.rst 
b/gcc/ada/doc/gnat_rm/implementation_defined_attributes.rst
index e576fdbde8e..90da0a961ec 100644
--- a/gcc/ada/doc/gnat_rm/implementation_defined_attributes.rst
+++ b/gcc/ada/doc/gnat_rm/implementation_defined_attributes.rst
@@ -937,7 +937,7 @@ to set this restriction (if some unit does attempt to set 
it,
 the binder will refuse to bind the partition).
 
 Technical note: The restriction name and the unit name are
-intepreted entirely syntactically, as in the corresponding
+interpreted entirely syntactically, as in the corresponding
 Restrictions pragma, they are not analyzed semantically,
 so they do not have a type.
 
@@ -1067,7 +1067,7 @@ If the opposite storage order is specified, then whenever 
the value of
 a scalar component of an object of type ``S`` is read, the storage
 elements of the enclosing machine scalar are first reversed (before
 retrieving the component value, possibly applying some shift and mask
-operatings on the enclosing machine scalar), and the opposite operation
+operations on the enclosing machine scalar), and the opposite operation
 is done for writes.
 
 In that case, the restrictions set forth in 13.5.1(10.3/2) for scalar 
components
@@ -1089,7 +1089,7 @@ inheritance in the case of a derived type), then the 
default is normally
 the native ordering of the target, but this default can be overridden using
 pragma ``Default_Scalar_Storage_Order``.
 
-If a component of ``T`` is itself of a record or array type, the specfied
+If a component of ``T`` is itself of a record or array type, the specified
 ``Scalar_Storage_Order`` does *not* apply to that nested type: an explicit
 attribute definition clause must be provided for the component type as well
 if desired.
@@ -1304,7 +1304,7 @@ static expression and where the function call could not 
be used
 (since the function call is always nonstatic, even if its
 argument is static). The argument must be in the range
 -(2**(m-1)) .. 2**m-1, where m is the memory size
-(typically 32 or 64). Negative values are intepreted in a
+(typically 32 or 64). Negative values are interpreted in a
 modular manner (e.g., -1 means the same as 16#FFFF_FFFF# on
 a 32 bits machine).
 
@@ -1629,7 +1629,7 @@ begin unmodified. Similarly:
 
 
 yields a value for ``Rvar2`` of (A => 1, B => 20, C => 3),
-with ``Rvar1`` being unmodifed.
+with ``Rvar1`` being unmodified.
 Note that the value of the attribute reference is computed
 completely before it is used. This means that if you write:
 
diff --git a/gcc/ada/doc/gnat_rm/implementation_defined_characteristics.rst 
b/gcc/ada/doc/gnat_rm/implementation_defined_characteristics.rst
index 887cc110d66..49455d89545 100644
--- a/gcc/ada/doc/gnat_rm/implementation_defined_characteristics.rst
+++ b/gcc/ada/doc/gnat_rm/implementation_defined_characteristics.rst
@@ -773,7 +773,7 @@ main program in the natural manner.
 These names are interpreted consistently with the underlying file system.
 
 *
-  "The maxium value for a file size in Directories.  See A.16(87)."
+  "The maximum value for a file size in Directories.  See A.16(87)."
 
 Directories.File_Size'Last is equal to Long_Long_Integer'Last .
 
diff --git a/gcc/ada/doc/gnat_rm/implementation_defined_pragmas.rst 
b/gcc/ada/doc/gnat_rm/implementation_defined_pragmas.rst
index fe52317fb67..bb7826f9938 100644
--- a/gcc/ada/doc/gnat_rm/implementation_defined_pragmas.rst
+++ b/gcc/ada/doc/gnat_rm/implementation_defined_pragmas.rst
@@ -485,7 +485,7 @@ except that in an ``Assertion_Policy`` pragma, the 
identifier
 (or disabled).
 
 The intention is that this be used within a subprogram when the
-given test expresion sums up all the work done so far in the
+given test expression sums up all the work done so far in the
 subprogram, so that the rest of the subprogram can be verified
 (informally or formally) using only the entry preconditions,
 and the expression in this pragma. This allows dividing up
@@ -4854,7 +4854,7 @@ checking is enabled.
 
 Note that pragma ``Postcondition`` differs from the language-defined
 ``Post`` aspect (and corresponding ``Post`` pragma) in allowing
-multiple occurrences, allowing occurences in the body even if there
+multiple occurrences, allowing occurrences in the body even if there
 is a separate spec, and allowing a second string parameter, and the
 use of the pragma identifier ``Check``. Historically, pragma
 ``Postcondition`` was implemented prior to the development of
@@ -4984,7 +4984,7 @@ checking is enabled.
 
 Note that pragma ``Precondition`` differs from the language-defined
 ``Pre`` aspect (and corresponding ``Pre`` pragma) in allowing
-multiple occurrences, allowing occurences in the body even if there
+multiple occurrences, allowing occurrences in the body even if there
 is a separate spec, and allowing a second string parameter, and the
 use of the pragma identifier ``Check``. Historically, pragma
 ``Precondition`` was implemented prior to the development of
diff --git a/gcc/ada/doc/gnat_rm/interfacing_to_other_languages.rst 
b/gcc/ada/doc/gnat_rm/interfacing_to_other_languages.rst
index 03cd3301b91..b3c5aad5fc8 100644
--- a/gcc/ada/doc/gnat_rm/interfacing_to_other_languages.rst
+++ b/gcc/ada/doc/gnat_rm/interfacing_to_other_languages.rst
@@ -269,7 +269,7 @@ True for all of these, as well as for any case in which
        ?? := Get_Unrelated_Obj_Acc (BEx): --  ditto, NO ERROR DETECTED!
     end;
 
-The calls marked with ``NO ERROR DETECTED!`` will compile sucessfully,
+The calls marked with ``NO ERROR DETECTED!`` will compile successfully,
 even though the types specified in the specializations of the generic
 function do not match the type of the exception object that the
 function is expected to return. Mismatches between derived and base
diff --git a/gcc/ada/doc/gnat_rm/representation_clauses_and_pragmas.rst 
b/gcc/ada/doc/gnat_rm/representation_clauses_and_pragmas.rst
index 8e46b378f65..e97c3fa621f 100644
--- a/gcc/ada/doc/gnat_rm/representation_clauses_and_pragmas.rst
+++ b/gcc/ada/doc/gnat_rm/representation_clauses_and_pragmas.rst
@@ -1948,7 +1948,7 @@ done for the case of anonymous access-to-subprogram.
 In GNAT, we decide that if an explicit Convention is applied
 to an object or component, and its type is such an anonymous type,
 then the convention will apply to this anonymous type as well. This
-seems to make sense since it is anomolous in any case to have a
+seems to make sense since it is anomalous in any case to have a
 different convention for an object and its type, and there is clearly
 no way to explicitly specify a convention for an anonymous type, since
 it doesn't have a name to specify!
diff --git 
a/gcc/ada/doc/gnat_rm/standard_and_implementation_defined_restrictions.rst 
b/gcc/ada/doc/gnat_rm/standard_and_implementation_defined_restrictions.rst
index 2945a124226..84d3708e14d 100644
--- a/gcc/ada/doc/gnat_rm/standard_and_implementation_defined_restrictions.rst
+++ b/gcc/ada/doc/gnat_rm/standard_and_implementation_defined_restrictions.rst
@@ -194,7 +194,7 @@ to support specific constructs of the language. Here are 
some examples:
 * ``System.Memory``: heap memory allocation routines,
 * ``System.Memory_Compare``: memory comparison routine (aka ``memcmp`` for C),
 * ``System.Memory_Copy``: memory copy routine (aka ``memcpy`` for C),
-* ``System.Memory_Move``: memoy move routine (aka ``memmove`` for C),
+* ``System.Memory_Move``: memory move routine (aka ``memmove`` for C),
 * ``System.Memory_Set``: memory set routine (aka ``memset`` for C),
 * ``System.Stack_Checking[.Operations]``: stack checking without MMU,
 * ``System.GCC``: support routines from the GCC library.
diff --git a/gcc/ada/doc/gnat_rm/the_gnat_library.rst 
b/gcc/ada/doc/gnat_rm/the_gnat_library.rst
index bd17490e5cf..466c0383209 100644
--- a/gcc/ada/doc/gnat_rm/the_gnat_library.rst
+++ b/gcc/ada/doc/gnat_rm/the_gnat_library.rst
@@ -642,7 +642,7 @@ multiple instantiations.
 
 .. index:: UTF-8 representation
 
-.. index:: Wide characte representations
+.. index:: Wide character representations
 
 Provides a routine which given a string, reads the start of the string to
 see whether it is one of the standard byte order marks (BOM's) which signal
diff --git a/gcc/ada/doc/gnat_ugn/building_executable_programs_with_gnat.rst 
b/gcc/ada/doc/gnat_ugn/building_executable_programs_with_gnat.rst
index b339d2579dd..03693b92af6 100644
--- a/gcc/ada/doc/gnat_ugn/building_executable_programs_with_gnat.rst
+++ b/gcc/ada/doc/gnat_ugn/building_executable_programs_with_gnat.rst
@@ -1616,7 +1616,7 @@ Alphabetical List of All Switches
 
 :switch:`-gnateH`
   Set the threshold from which the RM 13.5.1(13.3/2) clause applies to 64.
-  This is useful only on 64-bit plaforms where this threshold is 128, but
+  This is useful only on 64-bit platforms where this threshold is 128, but
   used to be 64 in earlier versions of the compiler.
 
 
diff --git a/gcc/ada/doc/gnat_ugn/gnat_and_program_execution.rst 
b/gcc/ada/doc/gnat_ugn/gnat_and_program_execution.rst
index 031fafcfa5a..671c8e9659c 100644
--- a/gcc/ada/doc/gnat_ugn/gnat_and_program_execution.rst
+++ b/gcc/ada/doc/gnat_ugn/gnat_and_program_execution.rst
@@ -647,7 +647,7 @@ using GNAT and your familiarity with compiler internals.
 Naming Conventions for GNAT Source Files
 ----------------------------------------
 
-In order to bettter understand the workings of the GNAT system, the following
+In order to better understand the workings of the GNAT system, the following
 brief description of its organization may be helpful:
 
 * Files with prefix :file:`sc` contain the lexical scanner.
@@ -2265,7 +2265,7 @@ aliasing optimizations are automatically suppressed for 
it.
 
 If it's not practical to move the unchecked conversion to the same unit
 in which the destination access type is declared (perhaps because the
-source type is not visible in that unit), the second possibiliy is for you to
+source type is not visible in that unit), the second possibility is for you to
 use pragma ``No_Strict_Aliasing`` for the type. You must place this pragma
 in the same declarative part as the declaration of the access type:
 
@@ -2421,7 +2421,7 @@ optimizations that assume the variable cannot be assigned 
to.  This
 means that the above example will in fact "work" reliably, that is, it
 will produce the expected results. However, you should nevertheless
 avoid code such as this if possible because it's not portable and may not
-functin as you expect with all compilers.
+function as you expect with all compilers.
 
 
 .. _Atomic_Variables_and_Optimization:
@@ -3043,7 +3043,7 @@ for code that is to be exported to some other compiler 
than GNAT.
 The Ada standard allows the reassociation of expressions at
 the same precedence level if no parentheses are present. For
 example, ``A+B+C`` parses as though it were ``(A+B)+C``, but
-the compiler can reintepret this as ``A+(B+C)``, possibly
+the compiler can reinterpret this as ``A+(B+C)``, possibly
 introducing or eliminating an overflow exception. The GNAT
 compiler never takes advantage of this freedom, and the
 expression ``A+B+C`` will be evaluated as ``(A+B)+C``.
@@ -3552,7 +3552,7 @@ given in kilobytes. For example:
 would specify to the analyzer that the environment task stack has a limit
 of 1.6 megabytes. Any stack usage beyond this will be ignored by the analysis.
 
-This is not suppored by the LLVM back end.
+This is not supported by the LLVM back end.
 
 The package ``GNAT.Task_Stack_Usage`` provides facilities to get
 stack-usage reports at run time. See its body for the details.
diff --git a/gcc/ada/doc/gnat_ugn/gnat_utility_programs.rst 
b/gcc/ada/doc/gnat_ugn/gnat_utility_programs.rst
index d1011be2c0b..4ec6b0e5ef7 100644
--- a/gcc/ada/doc/gnat_ugn/gnat_utility_programs.rst
+++ b/gcc/ada/doc/gnat_ugn/gnat_utility_programs.rst
@@ -602,7 +602,7 @@ building specialized scripts.
      * Places each keyword ``use`` in USE clauses on a separate line
      * Splits the line just before the keyword ``record`` in a RECORD type
        declaration
-     * Indents named blocks and loop statments with respect to the name
+     * Indents named blocks and loop statements with respect to the name
      * When necessary, splits binary operators always before the operator
      * Inserts an extra blank before various occurrences of ``(`` and ``:``
      * When it is necessary to split a line between two subexpressions (because
@@ -1069,7 +1069,7 @@ building specialized scripts.
      If you specify a project file but don't specify a source file,
      either directly or by means of a :switch:`--files` option,
      ``gnatpp`` processes all the units of the closure of the
-     specifed project. Otherwise this option has no effect.
+     specified project. Otherwise this option has no effect.
 
    :switch:`-U {main_unit}`
      If you specify a project file but don't specify a source file,
diff --git a/gcc/ada/doc/gnat_ugn/platform_specific_information.rst 
b/gcc/ada/doc/gnat_ugn/platform_specific_information.rst
index 6493a065960..f710f7c5715 100644
--- a/gcc/ada/doc/gnat_ugn/platform_specific_information.rst
+++ b/gcc/ada/doc/gnat_ugn/platform_specific_information.rst
@@ -292,7 +292,7 @@ This gets the effective user id and if it's not 0 (i.e. 
root), it raises
 Program_Error. Note that if you're running the code in a container, this may
 not be sufficient as you may have sufficient privilege on the container,
 but not on the host machine running the container, so check that you also
-have sufficient priviledge for running the container image.
+have sufficient privilege for running the container image.
 
 .. _A_GNU_Linux_debug_quirk:
 
@@ -586,7 +586,7 @@ least the following data::
    </assembly>
 
 Without the manifest file, the socket timeout will be overcorrected on
-these Windows Server versions and the actual time wil be 500
+these Windows Server versions and the actual time will be 500
 milliseconds shorter than what was set with
 ``GNAT.Sockets.Set_Socket_Option``.  Note that on Microsoft Windows
 versions where correction is necessary, there is no way to set a
diff --git a/gcc/ada/doc/gnat_ugn/the_gnat_compilation_model.rst 
b/gcc/ada/doc/gnat_ugn/the_gnat_compilation_model.rst
index 94b41b52adf..19e3c12c5b3 100644
--- a/gcc/ada/doc/gnat_ugn/the_gnat_compilation_model.rst
+++ b/gcc/ada/doc/gnat_ugn/the_gnat_compilation_model.rst
@@ -368,7 +368,7 @@ An exception occurs if the file name generated by the above 
rules starts
 with one of the characters
 ``a``, ``g``, ``i``, or ``s`` and the second character is a
 hyphen. In this case, the character tilde is used in place
-of the hypen. This special rule avoids clashes with
+of the hyphen. This special rule avoids clashes with
 the standard names for child units of the packages ``System``, ``Ada``,
 ``Interfaces``, and ``GNAT``, which use the prefixes
 ``s-``, ``a-``, ``i-``, and ``g-``,
@@ -3907,7 +3907,7 @@ use of a foreign linker for the last phase. We consider 
three cases:
   mechanism used.
 
   If you are using the ``setjmp`` / ``longjmp`` exception mechanism, you need 
only
-  inclue the paths to the ``libgcc`` libraries:
+  include the paths to the ``libgcc`` libraries:
 
   .. code-block:: sh
 
diff --git a/gcc/ada/doc/share/conf.py b/gcc/ada/doc/share/conf.py
index 4773ac96e39..a2009a267f6 100644
--- a/gcc/ada/doc/share/conf.py
+++ b/gcc/ada/doc/share/conf.py
@@ -150,7 +150,7 @@ if os.path.isfile('favicon.ico'):
 
 html_static_path = ['_static']
 
-# Use gnat.sty for bulding documents
+# Use gnat.sty for building documents
 latex_additional_files = ['gnat.sty']
 
 # Add copyright info to file
diff --git a/gcc/ada/gcc-interface/decl.cc b/gcc/ada/gcc-interface/decl.cc
index 4ccc8d7a0e1..7f39113186f 100644
--- a/gcc/ada/gcc-interface/decl.cc
+++ b/gcc/ada/gcc-interface/decl.cc
@@ -8919,7 +8919,7 @@ components_to_record (Node_Id gnat_component_list, 
Entity_Id gnat_record_type,
      self-referential/variable offset or misaligned.  Note, in the latter
      case, that this can only happen in packed record types so the alignment
      is effectively capped to the byte for the whole record.  But we don't
-     do it for packed record types if not all fixed-size fiels can be packed
+     do it for packed record types if not all fixed-size fields can be packed
      and for non-packed record types if pragma Optimize_Alignment (Space) is
      specified, because this can prevent alignment gaps from being filled.
 
diff --git a/gcc/ada/gcc-interface/trans.cc b/gcc/ada/gcc-interface/trans.cc
index 6db0aa0a6be..6eca5a49cd5 100644
--- a/gcc/ada/gcc-interface/trans.cc
+++ b/gcc/ada/gcc-interface/trans.cc
@@ -3224,7 +3224,7 @@ Loop_Statement_to_gnu (Node_Id gnat_node)
       gnat_pushlevel ();
 
       /* If we use the special induction variable, create it and set it to
-        its initial value.  Morever, the regular iteration variable cannot
+        its initial value.  Moreover, the regular iteration variable cannot
         itself be initialized, lest the initial value wrapped around.  */
       if (use_iv)
        {
@@ -8439,7 +8439,7 @@ gnat_to_gnu (Node_Id gnat_node)
          /* Get the value to use as the address and save it as the equivalent
             for the object; when it is frozen, gnat_to_gnu_entity will do the
             right thing.  For a subprogram, put the naked address but build a
-            meaningfull expression for an object in case its address is taken
+            meaningful expression for an object in case its address is taken
             before the Freeze node is encountered; this can happen if the type
             of the object is limited and it is initialized with the result of
             a function call.  */
diff --git a/gcc/ada/gcc-interface/utils.cc b/gcc/ada/gcc-interface/utils.cc
index 3da24fdb61a..f4fc0cec828 100644
--- a/gcc/ada/gcc-interface/utils.cc
+++ b/gcc/ada/gcc-interface/utils.cc
@@ -937,7 +937,7 @@ gnat_pushdecl (tree decl, Node_Id gnat_node)
   /* Mark functions really nested in another function, that is to say defined
      there as opposed to imported from elsewhere, as initially needing a static
      chain for the sake of uniformity (lower_nested_functions will recompute it
-     exacly later) and as private to the translation unit (the static chain may
+     exactly later) and as private to the translation unit (the static chain 
may
      be clobbered by calling conventions used across translation units).  */
   if (TREE_CODE (decl) == FUNCTION_DECL
       && !DECL_EXTERNAL (decl)
@@ -1857,7 +1857,7 @@ maybe_pad_type (tree type, tree size, unsigned int align,
        }
 
       /* There is no need to show what we are a subtype of when outputting as
-        few encodings as possible: regular debugging infomation makes this
+        few encodings as possible: regular debugging information makes this
         redundant.  */
       if (gnat_encodings == DWARF_GNAT_ENCODINGS_ALL)
        {
@@ -2383,7 +2383,7 @@ finish_record_type (tree record_type, tree field_list, 
int rep_level,
             the REP part of a record with a variant part for which the
             variant part has a rep clause but not the fixed part, in
             which case this REP part may contain overlapping fields
-            and thus needs to be treated like a union tyoe above, so
+            and thus needs to be treated like a union type above, so
             use a MAX in that case.  Also, if this field is a variant
             part, we need to take into account the previous size in
             the case of empty variants.  */
@@ -3588,7 +3588,7 @@ process_deferred_decl_context (bool force)
          processed = true;
        }
 
-      /* If this node has been successfuly processed, remove it from the
+      /* If this node has been successfully processed, remove it from the
         queue.  Then move to the next node.  */
       if (processed)
        {
diff --git a/gcc/ada/gnat_rm.texi b/gcc/ada/gnat_rm.texi
index 74c8f747b49..09520408502 100644
--- a/gcc/ada/gnat_rm.texi
+++ b/gcc/ada/gnat_rm.texi
@@ -1970,7 +1970,7 @@ except that in an @code{Assertion_Policy} pragma, the 
identifier
 (or disabled).
 
 The intention is that this be used within a subprogram when the
-given test expresion sums up all the work done so far in the
+given test expression sums up all the work done so far in the
 subprogram, so that the rest of the subprogram can be verified
 (informally or formally) using only the entry preconditions,
 and the expression in this pragma. This allows dividing up
@@ -6442,7 +6442,7 @@ checking is enabled.
 
 Note that pragma @code{Postcondition} differs from the language-defined
 @code{Post} aspect (and corresponding @code{Post} pragma) in allowing
-multiple occurrences, allowing occurences in the body even if there
+multiple occurrences, allowing occurrences in the body even if there
 is a separate spec, and allowing a second string parameter, and the
 use of the pragma identifier @code{Check}. Historically, pragma
 @code{Postcondition} was implemented prior to the development of
@@ -6573,7 +6573,7 @@ checking is enabled.
 
 Note that pragma @code{Precondition} differs from the language-defined
 @code{Pre} aspect (and corresponding @code{Pre} pragma) in allowing
-multiple occurrences, allowing occurences in the body even if there
+multiple occurrences, allowing occurrences in the body even if there
 is a separate spec, and allowing a second string parameter, and the
 use of the pragma identifier @code{Check}. Historically, pragma
 @code{Precondition} was implemented prior to the development of
@@ -11901,7 +11901,7 @@ to set this restriction (if some unit does attempt to 
set it,
 the binder will refuse to bind the partition).
 
 Technical note: The restriction name and the unit name are
-intepreted entirely syntactically, as in the corresponding
+interpreted entirely syntactically, as in the corresponding
 Restrictions pragma, they are not analyzed semantically,
 so they do not have a type.
 
@@ -12079,7 +12079,7 @@ inheritance in the case of a derived type), then the 
default is normally
 the native ordering of the target, but this default can be overridden using
 pragma @code{Default_Scalar_Storage_Order}.
 
-If a component of @code{T} is itself of a record or array type, the specfied
+If a component of @code{T} is itself of a record or array type, the specified
 @code{Scalar_Storage_Order} does `not' apply to that nested type: an explicit
 attribute definition clause must be provided for the component type as well
 if desired.
@@ -12319,7 +12319,7 @@ static expression and where the function call could not 
be used
 (since the function call is always nonstatic, even if its
 argument is static). The argument must be in the range
 -(2**(m-1)) .. 2**m-1, where m is the memory size
-(typically 32 or 64). Negative values are intepreted in a
+(typically 32 or 64). Negative values are interpreted in a
 modular manner (e.g., -1 means the same as 16#FFFF_FFFF# on
 a 32 bits machine).
 
@@ -12662,7 +12662,7 @@ Rvar2 : Rec := Rvar1'Update (B => 20);
 @end example
 
 yields a value for @code{Rvar2} of (A => 1, B => 20, C => 3),
-with @code{Rvar1} being unmodifed.
+with @code{Rvar1} being unmodified.
 Note that the value of the attribute reference is computed
 completely before it is used. This means that if you write:
 
@@ -13162,7 +13162,7 @@ to support specific constructs of the language. Here 
are some examples:
 @code{System.Memory_Copy}: memory copy routine (aka @code{memcpy} for C),
 
 @item 
-@code{System.Memory_Move}: memoy move routine (aka @code{memmove} for C),
+@code{System.Memory_Move}: memory move routine (aka @code{memmove} for C),
 
 @item 
 @code{System.Memory_Set}: memory set routine (aka @code{memset} for C),
@@ -17654,7 +17654,7 @@ These names are interpreted consistently with the 
underlying file system.
 @itemize *
 
 @item 
-“The maxium value for a file size in Directories.  See A.16(87).”
+“The maximum value for a file size in Directories.  See A.16(87).”
 @end itemize
 
 Directories.File_Size’Last is equal to Long_Long_Integer’Last .
@@ -21133,7 +21133,7 @@ done for the case of anonymous access-to-subprogram.
 In GNAT, we decide that if an explicit Convention is applied
 to an object or component, and its type is such an anonymous type,
 then the convention will apply to this anonymous type as well. This
-seems to make sense since it is anomolous in any case to have a
+seems to make sense since it is anomalous in any case to have a
 different convention for an object and its type, and there is clearly
 no way to explicitly specify a convention for an anonymous type, since
 it doesn’t have a name to specify!
@@ -24512,7 +24512,7 @@ multiple instantiations.
 
 @geindex UTF-8 representation
 
-@geindex Wide characte representations
+@geindex Wide character representations
 
 Provides a routine which given a string, reads the start of the string to
 see whether it is one of the standard byte order marks (BOM’s) which signal
@@ -26423,7 +26423,7 @@ exception
 end;
 @end example
 
-The calls marked with @code{NO ERROR DETECTED!} will compile sucessfully,
+The calls marked with @code{NO ERROR DETECTED!} will compile successfully,
 even though the types specified in the specializations of the generic
 function do not match the type of the exception object that the
 function is expected to return. Mismatches between derived and base
@@ -32561,7 +32561,7 @@ shall have a Size that does not exceed the specified 
value; and
 
 @item 
 shall have a (possibly inherited) @code{Size'Class} aspect that does not exceed
-the specifed value; and
+the specified value; and
 
 @item 
 shall be undiscriminated; and
diff --git a/gcc/ada/gnat_ugn.texi b/gcc/ada/gnat_ugn.texi
index e8ed558a62f..13f145b0261 100644
--- a/gcc/ada/gnat_ugn.texi
+++ b/gcc/ada/gnat_ugn.texi
@@ -1553,7 +1553,7 @@ An exception occurs if the file name generated by the 
above rules starts
 with one of the characters
 @code{a}, @code{g}, @code{i}, or @code{s} and the second character is a
 hyphen. In this case, the character tilde is used in place
-of the hypen. This special rule avoids clashes with
+of the hyphen. This special rule avoids clashes with
 the standard names for child units of the packages @code{System}, @code{Ada},
 @code{Interfaces}, and @code{GNAT}, which use the prefixes
 @code{s-}, @code{a-}, @code{i-}, and @code{g-},
@@ -5822,7 +5822,7 @@ a few more parameters to the link command line, depending 
on the exception
 mechanism used.
 
 If you are using the @code{setjmp} / @code{longjmp} exception mechanism, you 
need only
-inclue the paths to the @code{libgcc} libraries:
+include the paths to the @code{libgcc} libraries:
 
 @example
 $ cat ./my_script
@@ -9195,7 +9195,7 @@ blank lines.
 @item @code{-gnateH}
 
 Set the threshold from which the RM 13.5.1(13.3/2) clause applies to 64.
-This is useful only on 64-bit plaforms where this threshold is 128, but
+This is useful only on 64-bit platforms where this threshold is 128, but
 used to be 64 in earlier versions of the compiler.
 @end table
 
@@ -19158,7 +19158,7 @@ the source file.
 @subsection Naming Conventions for GNAT Source Files
 
 
-In order to bettter understand the workings of the GNAT system, the following
+In order to better understand the workings of the GNAT system, the following
 brief description of its organization may be helpful:
 
 
@@ -21080,7 +21080,7 @@ aliasing optimizations are automatically suppressed for 
it.
 
 If it’s not practical to move the unchecked conversion to the same unit
 in which the destination access type is declared (perhaps because the
-source type is not visible in that unit), the second possibiliy is for you to
+source type is not visible in that unit), the second possibility is for you to
 use pragma @code{No_Strict_Aliasing} for the type. You must place this pragma
 in the same declarative part as the declaration of the access type:
 
@@ -21256,7 +21256,7 @@ optimizations that assume the variable cannot be 
assigned to.  This
 means that the above example will in fact “work” reliably, that is, it
 will produce the expected results. However, you should nevertheless
 avoid code such as this if possible because it’s not portable and may not
-functin as you expect with all compilers.
+function as you expect with all compilers.
 
 @node Atomic Variables and Optimization,Passive Task Optimization,Aliased 
Variables and Optimization,Performance Considerations
 @anchor{gnat_ugn/gnat_and_program_execution 
atomic-variables-and-optimization}@anchor{196}@anchor{gnat_ugn/gnat_and_program_execution
 id38}@anchor{197}
@@ -21972,7 +21972,7 @@ for code that is to be exported to some other compiler 
than GNAT.
 The Ada standard allows the reassociation of expressions at
 the same precedence level if no parentheses are present. For
 example, @code{A+B+C} parses as though it were @code{(A+B)+C}, but
-the compiler can reintepret this as @code{A+(B+C)}, possibly
+the compiler can reinterpret this as @code{A+(B+C)}, possibly
 introducing or eliminating an overflow exception. The GNAT
 compiler never takes advantage of this freedom, and the
 expression @code{A+B+C} will be evaluated as @code{(A+B)+C}.
@@ -22600,7 +22600,7 @@ $ set GNAT_STACK_LIMIT 1600
 would specify to the analyzer that the environment task stack has a limit
 of 1.6 megabytes. Any stack usage beyond this will be ignored by the analysis.
 
-This is not suppored by the LLVM back end.
+This is not supported by the LLVM back end.
 
 The package @code{GNAT.Task_Stack_Usage} provides facilities to get
 stack-usage reports at run time. See its body for the details.
@@ -23700,7 +23700,7 @@ This gets the effective user id and if it’s not 0 (i.e. 
root), it raises
 Program_Error. Note that if you’re running the code in a container, this may
 not be sufficient as you may have sufficient privilege on the container,
 but not on the host machine running the container, so check that you also
-have sufficient priviledge for running the container image.
+have sufficient privilege for running the container image.
 
 @node A GNU/Linux Debug Quirk,,Choosing the Scheduling Policy with 
GNU/Linux,GNU/Linux Topics
 @anchor{gnat_ugn/platform_specific_information 
a-gnu-linux-debug-quirk}@anchor{1cd}@anchor{gnat_ugn/platform_specific_information
 id8}@anchor{1ce}
@@ -24041,7 +24041,7 @@ least the following data:
 @end example
 
 Without the manifest file, the socket timeout will be overcorrected on
-these Windows Server versions and the actual time wil be 500
+these Windows Server versions and the actual time will be 500
 milliseconds shorter than what was set with
 @code{GNAT.Sockets.Set_Socket_Option}.  Note that on Microsoft Windows
 versions where correction is necessary, there is no way to set a
diff --git a/gcc/ada/gnathtml.pl b/gcc/ada/gnathtml.pl
index 548fde1ef0c..a6beadd29f8 100644
--- a/gcc/ada/gnathtml.pl
+++ b/gcc/ada/gnathtml.pl
@@ -24,7 +24,7 @@
 #-----------------------------------------------------------------------------
 
 ## This script converts an Ada file (and its dependency files) to Html.
-## Keywords, comments and strings are color-hilighted. If the cross-referencing
+## Keywords, comments and strings are color-highlighted. If the 
cross-referencing
 ## information provided by Gnat (when not using the -gnatx switch) is found,
 ## the html files will also have some cross-referencing features, i.e. if you
 ## click on a type, its declaration will be displayed.
diff --git a/gcc/ada/gsocket.h b/gcc/ada/gsocket.h
index cc92070598c..bc10d17c649 100644
--- a/gcc/ada/gsocket.h
+++ b/gcc/ada/gsocket.h
@@ -241,7 +241,7 @@
 #endif
 
 /*
- * Properties of the unerlying NetDB library:
+ * Properties of the underlying NetDB library:
  *   Need_Netdb_Buffer __gnat_getXXXbyYYY expects a caller-supplied buffer
  *   Need_Netdb_Lock   __gnat_getXXXbyYYY expects the caller to ensure
  *                     mutual exclusion
diff --git a/gcc/ada/init.c b/gcc/ada/init.c
index 7aced7fe813..ac74156e077 100644
--- a/gcc/ada/init.c
+++ b/gcc/ada/init.c
@@ -1319,7 +1319,7 @@ __gnat_handle_vms_condition (int *sigargs, void *mechargs)
 
   extern int SYS$PUTMSG (void *, int (*)(), void *, unsigned long long);
 
-  /* If it was a DEC Ada specific condtiion, make it GNAT otherwise
+  /* If it was a DEC Ada specific condition, make it GNAT otherwise
      keep the old facility.  */
   if ((sigargs [1] & FAC_MASK) == DECADA_M_FACILITY)
     SYS$PUTMSG (sigargs, copy_msg, &gnat_facility,
@@ -1348,7 +1348,7 @@ __gnat_handle_vms_condition (int *sigargs, void *mechargs)
 void
 GNAT$STOP (int *sigargs)
 {
-   /* Note that there are no mechargs. We rely on the fact that condtions
+   /* Note that there are no mechargs. We rely on the fact that conditions
       raised from DEClib I/O do not require an "adjust".  Also the count
       will be off by 2, since LIB$STOP didn't get a chance to add the
       PC and PSL fields, so we bump it so PUTMSG comes out right.  */
@@ -2117,7 +2117,7 @@ __gnat_error_handler (int sig, siginfo_t *si, void *sc)
 #endif
 
   /* VxWorks will always mask out the signal during the signal handler and
-     will reenable it on a longjmp.  GNAT does not generate a longjmp to
+     will re-enable it on a longjmp.  GNAT does not generate a longjmp to
      return from a signal handler so the signal will still be masked unless
      we unmask it.  */
   sigprocmask (SIG_SETMASK, NULL, &mask);
diff --git a/gcc/ada/raise-gcc.c b/gcc/ada/raise-gcc.c
index eba92f4b19f..c264f8fc204 100644
--- a/gcc/ada/raise-gcc.c
+++ b/gcc/ada/raise-gcc.c
@@ -381,7 +381,7 @@ db_phases (int phases)
    by a function. Such filter is emitted around the body of C++
    functions defined like:
      void foo ([...])  throw (A, B) { [...] }
-   These can be viewed as negativ filter: the landing pad is branched
+   These can be viewed as negative filter: the landing pad is branched
    to for exceptions that doesn't match the filter and usually aborts
    the program).
 
@@ -1545,7 +1545,7 @@ PERSONALITY_FUNCTION (_Unwind_State state,
       /* Phase 2, to call a cleanup.  */
       uw_phases = _UA_CLEANUP_PHASE;
 #if 0
-      /* ??? We don't use UA_HANDLER_FRAME (except to debug).  Futhermore,
+      /* ??? We don't use UA_HANDLER_FRAME (except to debug).  Furthermore,
         barrier_cache.sp isn't yet set.  */
       if (!(state & _US_FORCE_UNWIND)
          && (uw_exception->barrier_cache.sp
diff --git a/gcc/ada/rtinit.c b/gcc/ada/rtinit.c
index b9dec1f7a8f..c937936fd3f 100644
--- a/gcc/ada/rtinit.c
+++ b/gcc/ada/rtinit.c
@@ -446,7 +446,7 @@ __gnat_runtime_initialize (int install_handler)
                 && (_tcsstr (wargv[k], _T("?")) != 0 ||
                     _tcsstr (wargv[k], _T("*")) != 0))
               {
-                /* Wilcards are present, append all corresponding matches. */
+                /* Wildcards are present, append all corresponding matches. */
                 WIN32_FIND_DATA FileData;
                 HANDLE hDir = FindFirstFile (wargv[k], &FileData);
                 LPWSTR dir = NULL;
diff --git a/gcc/ada/sigtramp-arm-qnx.c b/gcc/ada/sigtramp-arm-qnx.c
index 219a96eceb7..f471f79eab0 100644
--- a/gcc/ada/sigtramp-arm-qnx.c
+++ b/gcc/ada/sigtramp-arm-qnx.c
@@ -43,7 +43,7 @@
    -- Prototypes for our internal asm stubs --
    -------------------------------------------
 
-   Eventhough our symbols will remain local, the prototype claims "extern"
+   Even though our symbols will remain local, the prototype claims "extern"
    and not "static" to prevent compiler complaints about a symbol used but
    never defined.  */
 
diff --git a/gcc/ada/sigtramp-vxworks-target.h 
b/gcc/ada/sigtramp-vxworks-target.h
index 64901130d46..b25c11853d2 100644
--- a/gcc/ada/sigtramp-vxworks-target.h
+++ b/gcc/ada/sigtramp-vxworks-target.h
@@ -138,7 +138,7 @@
 
 #elif defined (i386)
 
-/* These are the cfi colunm numbers */
+/* These are the cfi column numbers */
 
 #define REGNO_EDI 7
 #define REGNO_ESI 6
@@ -176,7 +176,7 @@
 
 #elif defined (__x86_64__)
 
-/* These are the cfi colunm numbers */
+/* These are the cfi column numbers */
 
 #define REGNO_RAX 0
 #define REGNO_RDX 1
diff --git a/gcc/ada/sigtramp-vxworks.c b/gcc/ada/sigtramp-vxworks.c
index ae5c1a3ba5b..15a613f483e 100644
--- a/gcc/ada/sigtramp-vxworks.c
+++ b/gcc/ada/sigtramp-vxworks.c
@@ -88,7 +88,7 @@ typedef struct ucontext
    -- Prototypes for our internal asm stubs --
    -------------------------------------------
 
-   Eventhough our symbols will remain local, the prototype claims "extern"
+   Even though our symbols will remain local, the prototype claims "extern"
    and not "static" to prevent compiler complaints about a symbol used but
    never defined.  */
 
diff --git a/gcc/ada/sysdep.c b/gcc/ada/sysdep.c
index 2185086aeb3..db479b70c06 100644
--- a/gcc/ada/sysdep.c
+++ b/gcc/ada/sysdep.c
@@ -100,7 +100,7 @@ extern struct tm *localtime_r(const time_t *, struct tm *);
 #include "adaint.h"
 
 /* Don't use macros versions of this functions on VxWorks since they cause
-   imcompatible changes in some VxWorks versions */
+   incompatible changes in some VxWorks versions */
 #ifdef __vxworks
 #undef getchar
 #undef putchar
diff --git a/gcc/ada/terminals.c b/gcc/ada/terminals.c
index 89537e5f982..c21a3259217 100644
--- a/gcc/ada/terminals.c
+++ b/gcc/ada/terminals.c
@@ -1158,7 +1158,7 @@ __gnat_setup_winsize (void *desc ATTRIBUTE_UNUSED,
 #define USE_CLONE_DEVICE "/dev/ptc"
 #elif defined (__hpux__)
 /* On HP-UX we use the streamed version. Using the non streamed version is not
-   recommanded (through "/dev/ptym/clone"). Indeed it seems that there are
+   recommended (through "/dev/ptym/clone"). Indeed it seems that there are
    issues to detect process terminations. */
 #define USE_CLONE_DEVICE "/dev/ptmx"
 #endif
@@ -1645,7 +1645,7 @@ __gnat_new_tty (void)
 /* __gnat_close_tty - close a terminal
  *
  * PARAMETERS
- *   desc  a pty_desc strucure
+ *   desc  a pty_desc structure
  */
 void __gnat_close_tty (pty_desc* desc)
 {
@@ -1656,7 +1656,7 @@ void __gnat_close_tty (pty_desc* desc)
 /* __gnat_tty_name - return slave side device name
  *
  * PARAMETERS
- *   desc  a pty_desc strucure
+ *   desc  a pty_desc structure
  * RETURN VALUE
  *   a string
  */
@@ -1669,7 +1669,7 @@ __gnat_tty_name (pty_desc* desc)
 /* __gnat_tty_name - return master side fd
  *
  * PARAMETERS
- *   desc  a pty_desc strucure
+ *   desc  a pty_desc structure
  * RETURN VALUE
  *   a fd
  */
diff --git a/gcc/ada/tracebak.c b/gcc/ada/tracebak.c
index baa75bbca76..17c6be11f88 100644
--- a/gcc/ada/tracebak.c
+++ b/gcc/ada/tracebak.c
@@ -341,7 +341,7 @@ struct layout
 #define FRAME_OFFSET(FP) 0
 #define PC_ADJUST -4
 
-/* Eventhough the base PPC ABI states that a toplevel frame entry
+/* Even though the base PPC ABI states that a toplevel frame entry
    should to feature a null backchain, AIX might expose a null return
    address instead.  */
 
diff --git a/gcc/ada/gcc-interface/misc.cc b/gcc/ada/gcc-interface/misc.cc
index 547aae5438c..505c48606a5 100644
--- a/gcc/ada/gcc-interface/misc.cc
+++ b/gcc/ada/gcc-interface/misc.cc
@@ -912,10 +912,10 @@ gnat_get_array_descr_info (const_tree const_type,
 
       if (is_array)
        {
          /* GDB does not handle very well the self-referencial bound
             expressions we are able to generate here for XUA types (they are
             used only by XUP encodings) so avoid them in this case.  Note that
-            there are two cases where we generate self-referencial bound
+            there are two cases where we generate self-referential bound
             expressions:  arrays that are constrained by record discriminants
             and XUA types.  */
          if (TYPE_CONTEXT (first_dimen)
@@ -1021,7 +1021,7 @@ get_array_bit_stride (tree comp_type)
   if (RECORD_OR_UNION_TYPE_P (comp_type) && !TYPE_FAT_POINTER_P (comp_type))
     return TYPE_ADA_SIZE (comp_type);
 
-  /* The gnat_get_array_descr_info debug hook expects a debug tyoe.  */
+  /* The gnat_get_array_descr_info debug hook expects a debug type.  */
   comp_type = maybe_debug_type (comp_type);
 
   /* Otherwise, see if this is an array we can analyze; if it's not, punt.  */
@@ -912,10 +912,10 @@ gnat_get_array_descr_info (const_tree const_type,
       if (is_array)
        {
-         /* GDB does not handle very well the self-referencial bound
+         /* GDB does not handle very well the self-referential bound
             expressions we are able to generate here for XUA types (they are
             used only by XUP encodings) so avoid them in this case.  Note that
-- 
2.43.0

Reply via email to